@@ -5,7 +5,7 @@ from bs4 import BeautifulSoup
 import json
 
 baseURL = "https://nn3.freenet.de/clevertanken/main.php?cm=1"
-baseURL = "http://130.61.217.10/main.php?cm=1"
+#baseURL = "http://130.61.217.10/main.php?cm=1"
 autogas = "Autogas"
 diesel = "Diesel"
 erdgas = "Erdgas"
@@ -16,9 +16,9 @@ FUEL = [autogas, diesel, erdgas, superplus, super, normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.17"
+        self.version = "1.0.19"
         self.author = "Ludy87"
-        self.project = "Ich tanke billig"
+        self.project = "Py Ich tanke billig"
         self.page = "https://www.astra-g.org/"
 
 def toJSON(self):
@@ -107,7 +107,7 @@ def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False
     else:
         return me
 
-def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = False):
+def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = '-1', asJson = False):
     stations = []
     for kraftstoff in kraftstoffe:
         me = ITBObject()
@@ -177,7 +177,7 @@ def getStationsA(kraftstoffe = FUEL, place_plz = '123', limit = -1, asJson = Fal
                         "fuel": kraftstoff,
                         "pos": i +1,
                     }
-                    if limit == i and limit != -1:
+                    if (limit == str(i)) and (limit != '-1'):
                         break
                     i += 1
                     if (FUEL[FUEL.index(kraftstoff)] == FUEL[0]):
